@@ -2,6 +2,7 @@
 use elbus::client::AsyncClient;
 use elbus::rpc::{Rpc, RpcClient, RpcError, RpcEvent, RpcResult};
 use elbus::QoS;
+use eva_common::acl::OIDMaskList;
 use eva_common::events::{
     ANY_STATE_TOPIC, LOCAL_STATE_TOPIC, LOG_INPUT_TOPIC, REMOTE_STATE_TOPIC, SERVICE_STATUS_TOPIC,
 };
@@ -20,7 +21,7 @@ use tokio::io::AsyncReadExt;
 use tokio::signal::unix::{signal, SignalKind};
 use tokio::time::sleep;
 
-#[derive(Debug, Copy, Clone)]
+#[derive(Debug, Copy, Clone, Eq, PartialEq)]
 pub enum EventKind {
     Local,
     Remote,
@@ -38,10 +39,11 @@ impl EventKind {
     }
 }
 
-pub async fn subscribe_oids<R: Rpc>(rpc: &R, oids: &[OID], kind: EventKind) -> EResult<()> {
-    let topics: Vec<String> = oids
+pub async fn subscribe_oids<R: Rpc>(rpc: &R, masks: &OIDMaskList, kind: EventKind) -> EResult<()> {
+    let topics: Vec<String> = masks
+        .oid_masks()
         .iter()
-        .map(|oid| format!("{}{}", kind.topic(), oid.to_path()))
+        .map(|mask| format!("{}{}", kind.topic(), mask.to_path()))
         .collect();
     rpc.client()
         .lock()
