@@ -1,3 +1,4 @@
+use eva_common::events::RawStateEventOwned;
 use eva_common::prelude::*;
 use serde::{Deserialize, Deserializer, Serialize, Serializer};
 use std::fmt;
@@ -30,6 +31,20 @@ pub struct ShortItemState {
     pub value: Option<Value>,
 }
 
+impl ShortItemState {
+    #[inline]
+    pub fn into_raw_state_event_owned(self) -> (OID, RawStateEventOwned) {
+        (
+            self.oid,
+            if let Some(value) = self.value {
+                RawStateEventOwned::new(self.status, value)
+            } else {
+                RawStateEventOwned::new0(self.status)
+            },
+        )
+    }
+}
+
 #[derive(Serialize, Deserialize, Clone, Debug)]
 pub struct HistoricalState {
     #[serde(skip_serializing_if = "Option::is_none")]
